@@ -21,7 +21,7 @@ func main() {
 
 	// Setup close handler
 	go func() {
-		c := make(chan os.Signal)
+		c := make(chan os.Signal,1) //added size 1 to channel buffer
 		signal.Notify(c, os.Interrupt, syscall.SIGTERM)
 		go func() {
 			<-c
