@@ -25,8 +25,8 @@ func NewRunner(options *Options) (*Runner, error) {
 		OutputDirectory:             options.OutputDirectory,
 		RequestDSL:                  options.RequestDSL,
 		ResponseDSL:                 options.ResponseDSL,
-		UpstreamHTTPProxies:         strings.Split(options.UpstreamHTTPProxies, ","),
-		UpstreamSock5Proxies:        strings.Split(options.UpstreamSocks5Proxies, ","),
+		UpstreamHTTPProxies:         options.UpstreamHTTPProxies,
+		UpstreamSock5Proxies:        options.UpstreamSocks5Proxies,
 		ListenDNSAddr:               options.ListenDNSAddr,
 		DNSMapping:                  options.DNSMapping,
 		DNSFallbackResolver:         options.DNSFallbackResolver,
