@@ -125,6 +125,7 @@ func (p *Proxy) OnResponse(resp *http.Response, ctx *goproxy.ProxyCtx) *http.Res
 		resp = p.MatchReplaceResponse(resp)
 	}
 
+	p.logger.LogResponse(resp, userdata) //nolint
 	ctx.UserData = userdata
 	return resp
 }
@@ -285,7 +286,7 @@ func (p *Proxy) Run() error {
 			if err != nil {
 				return err
 			}
-			httpProxyPortUint, err := strconv.ParseInt(httpProxyPort, 10, 32)
+			httpProxyPortUint, err := strconv.ParseUint(httpProxyPort, 10, 16)
 			if err != nil {
 				return err
 			}
